@@ -2,9 +2,9 @@ package Crypt::AuthEnc::CCM;
 
 use strict;
 use warnings;
-our $VERSION = '0.056';
+our $VERSION = '0.063';
 
-use base qw(Crypt::AuthEnc Exporter);
+require Exporter; our @ISA = qw(Exporter); ### use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw( ccm_encrypt_authenticate ccm_decrypt_verify )] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
@@ -12,50 +12,8 @@ our @EXPORT = qw();
 use Carp;
 $Carp::Internal{(__PACKAGE__)}++;
 use CryptX;
-use Crypt::Cipher;
 
-sub new {
-  my $class = shift;
-  local $SIG{__DIE__} = \&CryptX::_croak;
-  return _new(Crypt::Cipher::_trans_cipher_name(shift), @_);
-}
-
-sub ccm_encrypt_authenticate {
-  my $cipher_name = shift;
-  my $key = shift;
-  my $iv = shift;
-  my $adata = shift;
-  my $tag_len = shift;
-  my $plaintext = shift;
-
-  $iv = "" if !defined $iv;
-  $adata = "" if !defined $adata;
-  $plaintext = "" if !defined $plaintext;
-
-  local $SIG{__DIE__} = \&CryptX::_croak;
-  my $m = Crypt::AuthEnc::CCM->new($cipher_name, $key, $iv, $adata, $tag_len, length($plaintext));
-  my $ct = $m->encrypt_add($plaintext);
-  my $tag = $m->encrypt_done();
-  return ($ct, $tag);
-}
-
-sub ccm_decrypt_verify {
-  my $cipher_name = shift;
-  my $key = shift;
-  my $iv = shift;
-  my $adata = shift;
-  my $ciphertext = shift;
-  my $tag = shift;
-
-  $iv = "" if !defined $iv;
-  $adata = "" if !defined $adata;
-  $ciphertext = "" if !defined $ciphertext;
-
-  local $SIG{__DIE__} = \&CryptX::_croak;
-  my $m = Crypt::AuthEnc::CCM->new($cipher_name, $key, $iv, $adata, length($tag), length($ciphertext));
-  my $pt = $m->decrypt_add($ciphertext);
-  return $m->decrypt_done($tag) ? $pt : undef;
-}
+sub CLONE_SKIP { 1 } # prevent cloning
 
 1;
 
