@@ -2,7 +2,7 @@ package Crypt::KeyDerivation;
 
 use strict;
 use warnings;
-our $VERSION = '0.056';
+our $VERSION = '0.063';
 
 require Exporter; our @ISA = qw(Exporter); ### use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(pbkdf1 pbkdf2 hkdf hkdf_expand hkdf_extract)] );
@@ -12,57 +12,6 @@ our @EXPORT = qw();
 use Carp;
 $Carp::Internal{(__PACKAGE__)}++;
 use CryptX;
-use Crypt::Digest;
-
-sub pbkdf1 {
-  my ($password, $salt, $iteration_count, $hash_name, $len) = @_;
-  $iteration_count ||= 5000;
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA256');
-  $len ||= 32;
-  local $SIG{__DIE__} = \&CryptX::_croak;
-  return _pkcs_5_alg1($password, $salt, $iteration_count, $hash_name, $len);
-}
-
-sub pbkdf2 {
-  my ($password, $salt, $iteration_count, $hash_name, $len) = @_;
-  $iteration_count ||= 5000;
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA256');
-  $len ||= 32;
-  local $SIG{__DIE__} = \&CryptX::_croak;
-  return _pkcs_5_alg2($password, $salt, $iteration_count, $hash_name, $len);
-}
-
-sub hkdf_extract {
-  # RFC: HKDF-Extract(salt, IKM, [Hash]) -> PRK
-  #my ($hash_name, $salt, $keying_material) = @_;
-  my ($keying_material, $salt, $hash_name) = @_;
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA256');
-  $salt = pack("H*", "00" x Crypt::Digest->hashsize($hash_name)) unless defined $salt; # according to rfc5869 defaults to HashLen zero octets
-  local $SIG{__DIE__} = \&CryptX::_croak;
-  return _hkdf_extract($hash_name, $salt, $keying_material);
-}
-
-sub hkdf_expand {
-  # RFC: HKDF-Expand(PRK, info, L, [Hash]) -> OKM
-  #my ($hash_name, $info, $keying_material, $len) = @_;
-  my ($keying_material, $hash_name, $len, $info) = @_;
-  $len ||= 32;
-  $info ||= '';
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA256');
-  local $SIG{__DIE__} = \&CryptX::_croak;
-  return _hkdf_expand($hash_name, $info, $keying_material, $len);
-}
-
-sub hkdf {
-  #my ($hash_name, $salt, $info, $keying_material, $len) = @_;
-  my ($keying_material, $salt, $hash_name, $len, $info) = @_;
-  $len ||= 32;
-  $info ||= '';
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA256');
-  $salt = pack("H*", "00" x Crypt::Digest->hashsize($hash_name)) unless defined $salt; # according to rfc5869 defaults to HashLen zero octets
-  local $SIG{__DIE__} = \&CryptX::_croak;
-  return _hkdf($hash_name, $salt, $info, $keying_material, $len);
-}
 
 1;
 
@@ -74,6 +23,8 @@ Crypt::KeyDerivation - PBKDF1, PBKDF2 and HKDF key derivation functions
 
 =head1 SYNOPSIS
 
+  use Crypt::KeyDerivation ':all';
+
   ### PBKDF1/2
   $derived_key1 = pbkdf1($password, $salt, $iteration_count, $hash_name, $len);
   $derived_key2 = pbkdf2($password, $salt, $iteration_count, $hash_name, $len);
