@@ -2,7 +2,7 @@ package Crypt::PK::DH;
 
 use strict;
 use warnings;
-our $VERSION = '0.056';
+our $VERSION = '0.063';
 
 require Exporter; our @ISA = qw(Exporter); ### use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw( dh_shared_secret )] );
@@ -168,10 +168,8 @@ my %DH_PARAMS = (
 );
 
 sub new {
-  my ($class, $f) = @_;
-  my $self = _new();
-  $self->import_key($f) if $f;
-  return  $self;
+  my $self = shift->_new();
+  return @_ > 0 ? $self->import_key(@_) : $self;
 }
 
 sub import_key {
