@@ -2,7 +2,7 @@ package Crypt::PK::RSA;
 
 use strict;
 use warnings;
-our $VERSION = '0.056';
+our $VERSION = '0.063';
 
 require Exporter; our @ISA = qw(Exporter); ### use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(rsa_encrypt rsa_decrypt rsa_sign_message rsa_verify_message rsa_sign_hash rsa_verify_hash)] );
@@ -10,20 +10,20 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
 
 use Carp;
+$Carp::Internal{(__PACKAGE__)}++;
 use CryptX;
 use Crypt::Digest qw(digest_data digest_data_b64u);
 use Crypt::Misc qw(read_rawfile encode_b64u decode_b64u encode_b64 decode_b64 pem_to_der der_to_pem);
 use Crypt::PK;
 
 sub new {
-  my ($class, $f, $p) = @_;
-  my $self = _new();
-  $self->import_key($f, $p) if $f;
-  return  $self;
+  my $self = shift->_new();
+  return @_ > 0 ? $self->import_key(@_) : $self;
 }
 
 sub export_key_pem {
   my ($self, $type, $password, $cipher) = @_;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   my $key = $self->export_key_der($type||'');
   return unless $key;
 
@@ -40,6 +40,7 @@ sub export_key_pem {
 
 sub export_key_jwk {
   my ($self, $type, $wanthash) = @_;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   my $kh = $self->key2hash;
   if ($type eq 'private') {
     return unless $kh->{N} && $kh->{e} && $kh->{d} && $kh->{p} && $kh->{q} && $kh->{dP} && $kh->{dQ} && $kh->{qP};
@@ -75,6 +76,7 @@ sub export_key_jwk {
 
 sub export_key_jwk_thumbprint {
   my ($self, $hash_name) = @_;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   $hash_name ||= 'SHA256';
   my $h = $self->export_key_jwk('public', 1);
   my $json = CryptX::_encode_json({kty=>$h->{kty}, n=>$h->{n}, e=>$h->{e}});
@@ -83,6 +85,7 @@ sub export_key_jwk_thumbprint {
 
 sub import_key {
   my ($self, $key, $password) = @_;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   croak "FATAL: undefined key" unless $key;
 
   # special case
@@ -125,11 +128,12 @@ sub import_key {
   elsif ($data =~ /-----BEGIN PRIVATE KEY-----(.*?)-----END/sg) {
     # PKCS#8 PrivateKeyInfo      (PEM header: BEGIN PRIVATE KEY)
     $data = pem_to_der($data, $password);
-    return $self->_import_pkcs8($data, $password) if $data;
+    return $self->_import_pkcs8($data, $password);
   }
   elsif ($data =~ /-----BEGIN ENCRYPTED PRIVATE KEY-----(.*?)-----END/sg) {
-    # XXX-TODO: PKCS#8 EncryptedPrivateKeyInfo (PEM header: BEGIN ENCRYPTED PRIVATE KEY)
-    croak "FATAL: encrypted pkcs8 RSA private keys are not supported";
+    # PKCS#8 PrivateKeyInfo      (PEM header: BEGIN ENCRYPTED PRIVATE KEY)
+    $data = pem_to_der($data, $password);
+    return $self->_import_pkcs8($data, $password);
   }
   elsif ($data =~ /^\s*(\{.*?\})\s*$/s) {
     # JSON Web Key (JWK) - http://tools.ietf.org/html/draft-ietf-jose-json-web-key
@@ -165,64 +169,11 @@ sub import_key {
   croak "FATAL: invalid or unsupported RSA key format";
 }
 
-sub encrypt {
-  my ($self, $data, $padding, $hash_name, $lparam) = @_;
-  $lparam ||= '';
-  $padding ||= 'oaep';
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA1');
-
-  return $self->_encrypt($data, $padding, $hash_name, $lparam);
-}
-
-sub decrypt {
-  my ($self, $data, $padding, $hash_name, $lparam) = @_;
-  $lparam ||= '';
-  $padding ||= 'oaep';
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA1');
-
-  return $self->_decrypt($data, $padding, $hash_name, $lparam);
-}
-
-sub sign_hash {
-  my ($self, $data, $hash_name, $padding, $saltlen) = @_;
-  $saltlen ||= 12;
-  $padding ||= 'pss';
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA1');
-
-  return $self->_sign($data, $padding, $hash_name, $saltlen);
-}
-
-sub sign_message {
-  my ($self, $data, $hash_name, $padding, $saltlen) = @_;
-  $saltlen ||= 12;
-  $padding ||= 'pss';
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA1');
-
-  return $self->_sign(digest_data($hash_name, $data), $padding, $hash_name, $saltlen);
-}
-
-sub verify_hash {
-  my ($self, $sig, $data, $hash_name, $padding, $saltlen) = @_;
-  $saltlen ||= 12;
-  $padding ||= 'pss';
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA1');
-
-  return $self->_verify($sig, $data, $padding, $hash_name, $saltlen);
-}
-
-sub verify_message {
-  my ($self, $sig, $data, $hash_name, $padding, $saltlen) = @_;
-  $saltlen ||= 12;
-  $padding ||= 'pss';
-  $hash_name = Crypt::Digest::_trans_digest_name($hash_name||'SHA1');
-
-  return $self->_verify($sig, digest_data($hash_name, $data), $padding, $hash_name, $saltlen);
-}
-
 ### FUNCTIONS
 
 sub rsa_encrypt {
   my $key = shift;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   $key = __PACKAGE__->new($key) unless ref $key;
   carp "FATAL: invalid 'key' param" unless ref($key) eq __PACKAGE__;
   return $key->encrypt(@_);
@@ -230,6 +181,7 @@ sub rsa_encrypt {
 
 sub rsa_decrypt {
   my $key = shift;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   $key = __PACKAGE__->new($key) unless ref $key;
   carp "FATAL: invalid 'key' param" unless ref($key) eq __PACKAGE__;
   return $key->decrypt(@_);
@@ -237,6 +189,7 @@ sub rsa_decrypt {
 
 sub rsa_sign_hash {
   my $key = shift;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   $key = __PACKAGE__->new($key) unless ref $key;
   carp "FATAL: invalid 'key' param" unless ref($key) eq __PACKAGE__;
   return $key->sign_hash(@_);
@@ -244,6 +197,7 @@ sub rsa_sign_hash {
 
 sub rsa_verify_hash {
   my $key = shift;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   $key = __PACKAGE__->new($key) unless ref $key;
   carp "FATAL: invalid 'key' param" unless ref($key) eq __PACKAGE__;
   return $key->verify_hash(@_);
@@ -251,6 +205,7 @@ sub rsa_verify_hash {
 
 sub rsa_sign_message {
   my $key = shift;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   $key = __PACKAGE__->new($key) unless ref $key;
   carp "FATAL: invalid 'key' param" unless ref($key) eq __PACKAGE__;
   return $key->sign_message(@_);
@@ -258,6 +213,7 @@ sub rsa_sign_message {
 
 sub rsa_verify_message {
   my $key = shift;
+  local $SIG{__DIE__} = \&CryptX::_croak;
   $key = __PACKAGE__->new($key) unless ref $key;
   carp "FATAL: invalid 'key' param" unless ref($key) eq __PACKAGE__;
   return $key->verify_message(@_);
@@ -463,7 +419,7 @@ Supported key formats:
  fyoy4t3yHT+/nw==
  -----END PRIVATE KEY-----
 
-=item * PKCS#8 encrypted private keys ARE NOT SUPPORTED YET!
+=item * PKCS#8 encrypted private keys - password protected keys (supported since: CryptX-0.062)
 
  -----BEGIN ENCRYPTED PRIVATE KEY-----
  MIICojAcBgoqhkiG9w0BDAEDMA4ECCQk+Rr1yzzcAgIIAASCAoD/mgpUFjxxM/Ty
