@@ -7,10 +7,7 @@
  * guarantee it works.
  */
 
-/* Implements ECC over Z/pZ for curve y^2 = x^3 + a*x + b
- *
- */
-#include "tomcrypt.h"
+#include "tomcrypt_private.h"
 
 /**
   @file ltc_ecc_points.c
@@ -49,6 +46,24 @@ void ltc_ecc_del_point(ecc_point *p)
    }
 }
 
+int ltc_ecc_set_point_xyz(ltc_mp_digit x, ltc_mp_digit y, ltc_mp_digit z, ecc_point *p)
+{
+   int err;
+   if ((err = ltc_mp.set_int(p->x, x)) != CRYPT_OK) return err;
+   if ((err = ltc_mp.set_int(p->y, y)) != CRYPT_OK) return err;
+   if ((err = ltc_mp.set_int(p->z, z)) != CRYPT_OK) return err;
+   return CRYPT_OK;
+}
+
+int ltc_ecc_copy_point(const ecc_point *src, ecc_point *dst)
+{
+   int err;
+   if ((err = ltc_mp.copy(src->x, dst->x)) != CRYPT_OK) return err;
+   if ((err = ltc_mp.copy(src->y, dst->y)) != CRYPT_OK) return err;
+   if ((err = ltc_mp.copy(src->z, dst->z)) != CRYPT_OK) return err;
+   return CRYPT_OK;
+}
+
 #endif
 /* ref:         $Format:%D$ */
 /* git commit:  $Format:%H$ */
