@@ -27,6 +27,7 @@
 #   define BN_MP_CMP_D_C
 #   define BN_MP_CMP_MAG_C
 #   define BN_MP_CNT_LSB_C
+#   define BN_MP_COMPLEMENT_C
 #   define BN_MP_COPY_C
 #   define BN_MP_COUNT_BITS_C
 #   define BN_MP_DIV_C
@@ -116,6 +117,10 @@
 #   define BN_MP_SUB_C
 #   define BN_MP_SUB_D_C
 #   define BN_MP_SUBMOD_C
+#   define BN_MP_TC_AND_C
+#   define BN_MP_TC_DIV_2D_C
+#   define BN_MP_TC_OR_C
+#   define BN_MP_TC_XOR_C
 #   define BN_MP_TO_SIGNED_BIN_C
 #   define BN_MP_TO_SIGNED_BIN_N_C
 #   define BN_MP_TO_UNSIGNED_BIN_C
@@ -147,12 +152,12 @@
 #   define BN_MP_INIT_MULTI_C
 #   define BN_MP_COPY_C
 #   define BN_MP_MOD_C
+#   define BN_MP_ISZERO_C
 #   define BN_MP_SET_C
 #   define BN_MP_DIV_2_C
 #   define BN_MP_ISODD_C
 #   define BN_MP_SUB_C
 #   define BN_MP_CMP_C
-#   define BN_MP_ISZERO_C
 #   define BN_MP_CMP_D_C
 #   define BN_MP_ADD_C
 #   define BN_MP_EXCH_C
@@ -241,6 +246,11 @@
 #   define BN_MP_ISZERO_C
 #endif
 
+#if defined(BN_MP_COMPLEMENT_C)
+#   define BN_MP_NEG_C
+#   define BN_MP_SUB_D_C
+#endif
+
 #if defined(BN_MP_COPY_C)
 #   define BN_MP_GROW_C
 #endif
@@ -390,7 +400,8 @@
 
 #if defined(BN_MP_FREAD_C)
 #   define BN_MP_ZERO_C
-#   define BN_MP_S_RMAP_C
+#   define BN_MP_S_RMAP_REVERSE_SZ_C
+#   define BN_MP_S_RMAP_REVERSE_C
 #   define BN_MP_MUL_D_C
 #   define BN_MP_ADD_D_C
 #   define BN_MP_CMP_D_C
@@ -462,9 +473,8 @@
 #endif
 
 #if defined(BN_MP_INVMOD_C)
-#   define BN_MP_ISZERO_C
-#   define BN_MP_ISODD_C
 #   define BN_MP_CMP_D_C
+#   define BN_MP_ISODD_C
 #   define BN_FAST_MP_INVMOD_C
 #   define BN_MP_INVMOD_SLOW_C
 #endif
@@ -541,6 +551,7 @@
 #endif
 
 #if defined(BN_MP_LSHD_C)
+#   define BN_MP_ISZERO_C
 #   define BN_MP_GROW_C
 #   define BN_MP_RSHD_C
 #endif
@@ -714,6 +725,8 @@
 
 #if defined(BN_MP_RADIX_SMAP_C)
 #   define BN_MP_S_RMAP_C
+#   define BN_MP_S_RMAP_REVERSE_C
+#   define BN_MP_S_RMAP_REVERSE_SZ_C
 #endif
 
 #if defined(BN_MP_RAND_C)
@@ -724,7 +737,8 @@
 
 #if defined(BN_MP_READ_RADIX_C)
 #   define BN_MP_ZERO_C
-#   define BN_MP_S_RMAP_C
+#   define BN_MP_S_RMAP_REVERSE_SZ_C
+#   define BN_MP_S_RMAP_REVERSE_C
 #   define BN_MP_MUL_D_C
 #   define BN_MP_ADD_D_C
 #   define BN_MP_ISZERO_C
@@ -904,6 +918,49 @@
 #   define BN_MP_MOD_C
 #endif
 
+#if defined(BN_MP_TC_AND_C)
+#   define BN_MP_ISNEG_C
+#   define BN_MP_COUNT_BITS_C
+#   define BN_MP_INIT_SET_INT_C
+#   define BN_MP_MUL_2D_C
+#   define BN_MP_INIT_C
+#   define BN_MP_ADD_C
+#   define BN_MP_CLEAR_C
+#   define BN_MP_AND_C
+#   define BN_MP_SUB_C
+#endif
+
+#if defined(BN_MP_TC_DIV_2D_C)
+#   define BN_MP_ISNEG_C
+#   define BN_MP_DIV_2D_C
+#   define BN_MP_ADD_D_C
+#   define BN_MP_SUB_D_C
+#endif
+
+#if defined(BN_MP_TC_OR_C)
+#   define BN_MP_ISNEG_C
+#   define BN_MP_COUNT_BITS_C
+#   define BN_MP_INIT_SET_INT_C
+#   define BN_MP_MUL_2D_C
+#   define BN_MP_INIT_C
+#   define BN_MP_ADD_C
+#   define BN_MP_CLEAR_C
+#   define BN_MP_OR_C
+#   define BN_MP_SUB_C
+#endif
+
+#if defined(BN_MP_TC_XOR_C)
+#   define BN_MP_ISNEG_C
+#   define BN_MP_COUNT_BITS_C
+#   define BN_MP_INIT_SET_INT_C
+#   define BN_MP_MUL_2D_C
+#   define BN_MP_INIT_C
+#   define BN_MP_ADD_C
+#   define BN_MP_CLEAR_C
+#   define BN_MP_XOR_C
+#   define BN_MP_SUB_C
+#endif
+
 #if defined(BN_MP_TO_SIGNED_BIN_C)
 #   define BN_MP_TO_UNSIGNED_BIN_C
 #endif
